import React from 'react';
import { withRouter } from 'react-router-dom';
import { connect } from 'react-redux';
import { notify } from 'react-notify-toast';

import ThemeForm from './ThemeForm';
import DefaultData from './DefaultData';

import {
  updateLoading,
  previewItems
} from '../../store';

class ThemeCreate extends React.Component {

  constructor(props) {
    super(props);

    this.state = {
      form: DefaultData,
    };

    this.saveSettings = this.saveSettings.bind(this);
    this.updateForm = this.updateForm.bind(this);
  }

  render() {
    return (
      <ThemeForm
        submitButton={this.submitButtonHtml()}
        updateForm={this.updateForm}
        form={this.state.form}
      />
    );
  }

  submitButtonHtml() {
    return (
      <button className="gs-instagram-button"
        onClick={this.saveSettings}
        >Add Shortcode</button>
    );
  }

  saveSettings() {
    this.props.updateLoading( true );

    jQuery.ajax({
      method: "POST",
      url: window.ajaxurl,
      data: {
        body: this.state.form,
        action: "gs_instagram_admin_ajax",
        route: "create_theme",
      }
    }).done( ( response ) => {
      notify.show( 'Theme created successfully!', 'success' );
      this.props.previewItems([]);
      this.props.history.push('/');
    }).fail( ( xhr ) => {
      if ( xhr.status == 422 ) {
        notify.show( xhr.responseJSON.data.message, 'error' );
      }
    }).always( () => {
      this.props.updateLoading( false );
    });
  }

  updateForm( name, value ) {
    var form = this.state.form;
    form[name] = value;
    this.setState( { form: form } );
  }

}

function mapDispatchToProps( dispatch ) {
  return {
    updateLoading: value => dispatch( updateLoading( value ) ),
    previewItems: value => dispatch( previewItems( value ) ),
  };
}

export default withRouter(
  connect(null, mapDispatchToProps)( ThemeCreate )
);
