import React from 'react';
import { withRouter } from 'react-router-dom';
import { connect } from 'react-redux';
import { notify } from 'react-notify-toast';

import ThemeForm from './ThemeForm';
import DefaultData from './DefaultData';

import { updateLoading, previewItems } from '../../store';

class ThemeEdit extends React.Component {

  constructor(props) {
    super(props);

    this.state = {
      form: DefaultData,
    };

    this.saveSettings = this.saveSettings.bind(this);
    this.updateLocalState = this.updateLocalState.bind(this);
    this.updateForm = this.updateForm.bind(this);
    this.saveSettingsResponse = this.saveSettingsResponse.bind(this);
  }

  render() {
    return (
      <ThemeForm
        submitButton={this.submitButtonHtml()}
        updateForm={this.updateForm}
        form={this.state.form}
      />
    );
  }

  submitButtonHtml() {
    return (
      <button className="gs-instagram-button"
        onClick={this.saveSettings}
        >Update Shortcode</button>
    );
  }

  saveSettings() {
    this.props.updateLoading( true );

    jQuery.ajax({
      method: "POST",
      url: window.ajaxurl,
      data: {
        body: this.state.form,
        action: "gs_instagram_admin_ajax",
        route: "update_theme",
      }
    }).done( this.saveSettingsResponse ).fail( ( xhr ) => {
      if ( xhr.status == 422 ) {
        notify.show( xhr.responseJSON.data.message, 'error' );
      }
    }).always( () => {
      this.props.updateLoading( false );
    });
  }

  componentDidMount() {
    this.props.updateLoading( true );
    jQuery.ajax( {
      method: "GET",
      url: window.ajaxurl,
      data: {
        body: {
          id: this.props.match.params.id,
        },
        action: 'gs_instagram_admin_ajax',
        route: 'get_theme',
      },
      success: ( response ) => {
        this.updateLocalState( response.data );

        this.props.updateLoading( false );
      }
    } );
  }

  updateLocalState( data ) {
    try {
      var metaData = JSON.parse( meta_data );
    } catch( error ) {
      metaData = {};
    }
    var form = {
      id: data.id,
      name: data.name,
      source: data.source,
      per_page: data.per_page,
      source_type: data.source_type,
      columns: data.columns,
      theme_style: data.theme_style,
      link_target: data.link_target,
      user_id: !! metaData.user_id ? metaData.user_id : null,
    };

    this.setState( { form: form } );
  }

  updateForm( name, value ) {
    var form = this.state.form;
    form[name] = value;
    this.setState( { form: form } );
  }

  saveSettingsResponse( response ) {
    notify.show( 'Theme updated successfully!', 'success' );

    // Remove necessary scripts
    if ( 'gsip-theme-5' == this.state.form.theme_style ) {
      jQuery('.gsip-theme-slider-row').owlCarousel( 'destroy' );
    }

    this.props.previewItems([]);
    this.props.history.push('/');
  }

}

function mapDispatchToProps( dispatch ) {
  return {
    updateLoading: value => dispatch( updateLoading( value ) ),
    previewItems: value => dispatch( previewItems( value ) ),
  };
}

export default withRouter(
  connect(null, mapDispatchToProps)( ThemeEdit )
);
