import React from 'react';
import { connect } from 'react-redux';

import ThemeSettings from './ThemeSettings';

import {
  previewLoading,
  previewItems,
  previewError
} from '../../store';

class ThemeForm extends React.Component {

  constructor(props) {
    super(props);

    this.handleChange = this.handleChange.bind(this);

    this.previewDataChnageTimer = null;
  }

  render() {
    var form = this.props.form;

    return (
      <div>
        <div className="gs-instagram-settings-field">
          <div className="gs-label">
            <label>Shortcode Name</label>
            <p>Give a meaningful name so that you find this theme easily in admin panel.</p>
          </div>
          <div className="gs-input">
            <input type="text" placeholder="Name your shortcode" className="default-input" name="name"
              value={form.name} onChange={this.handleChange}
            />
          </div>
        </div>

        <ThemeSettings form={form} handleChange={this.handleChange} />

        <div className="theme-create-submit">
          {this.props.submitButton}
          <span className="spinner gs-form-spinner" style={{ visibility: this.props.loading ? 'visible' : 'hidden' }}></span>
        </div>
      </div>
    );
  }

  handleChange( event ) {
    var value = event.target.value;
    var name = event.target.name;

    if ( name == 'per_page' && value < 1 ) {
      value = 1;
    }

    this.props.updateForm( name, value );

    switch ( name ) {
      case 'source':
      case 'source_type':
      case 'per_page':
        this.getPreviewData();
        break;
    }
  }

  getPreviewData() {
    clearTimeout(this.previewDataChnageTimer);

    this.previewDataChnageTimer = setTimeout(() => {
      this.props.previewLoading( true );
      this.props.previewError(false);
      jQuery.ajax({
        method: "GET",
        url: window.ajaxurl,
        data: {
          body: this.props.form,
          action: "gs_instagram_admin_ajax",
          route: "get_preview_data",
        }
      }).done( ( response ) => {
        this.props.previewItems( response.data.edges );
        this.props.updateForm( 'user_meta_data', response.data.user_meta_data );
      }).fail( ( xhr ) => {
        if ( xhr.status == 422 ) {
          this.props.previewError( xhr.responseJSON.data.message );
        }
      } ).always( () => {
        this.props.previewLoading( false );
      });
    }, 1000);
  }

  componentDidUpdate( prevProps ) {
    if ( prevProps && prevProps.form !== this.props.form ) {
      this.getPreviewData();
    }
  }

}

function mapStateToProps( state ) {
  return { loading: state.loading };
}

function mapDispatchToProps( dispatch ) {
  return {
    previewLoading: value => dispatch( previewLoading( value ) ),
    previewItems: value => dispatch( previewItems( value ) ),
    previewError: value => dispatch( previewError( value ) ),
  };
}

export default connect(mapStateToProps, mapDispatchToProps)( ThemeForm );
