import React from 'react';
import { connect } from 'react-redux';

import ThemesTableItem from './ThemesTableItem';
import { updateLoading } from '../../store';

class ThemesTable extends React.Component {

  constructor( props ) {
    super(props);

    this.state = {
      items: [],
    };

    this.themesNoItemHtml = this.themesNoItemHtml.bind(this);
    this.removeItem = this.removeItem.bind(this);
  }

  render() {
    return !!this.state.items.length ? this.themesTableHtml() : this.themesNoItemHtml();
  }

  componentDidMount() {
    this.props.updateLoading( true );
    jQuery.ajax( {
      method: "GET",
      url: window.ajaxurl + '?action=gs_instagram_admin_ajax&route=get_themes',
      success: ( response ) => {
        this.setState( { items: response.data } );
        this.props.updateLoading( false );
      }
    } );
  }

  themesTableHtml() {
    return (
      <table className="gs-instagram-table">
        <thead>
          <tr>
            <th>Name</th>
            <th>Shortcode</th>
            <th>Last updated</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>

          { this.state.items.map( ( item ) => (
            <ThemesTableItem
              item={item}
              key={item.id.toString()+item.name.toString()}
              removeItem={this.removeItem}
            />
          ) ) }

        </tbody>
      </table>
    );
  }

  themesNoItemHtml() {
    return (
      <table className="gs-instagram-table">
        <thead>
          <tr>
            { this.props.loading ?
              (<th>Loading...</th>) :
              (<th>You don't have any shortcode created, Please create a shortcode.</th>)
            }
          </tr>
        </thead>
      </table>
    );
  }

  removeItem( id ) {
    var items = this.state.items.filter(el => el.id != id );
    this.setState( { items: items } );
  }

}

function mapStateToProps(state) {
  return { loading: state.loading }
}

function mapDispatchToProps( dispatch ) {
  return {
    updateLoading: value => dispatch( updateLoading( value ) )
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(ThemesTable);
