import React from 'react';
import fecha from 'fecha';
import { NavLink } from "react-router-dom";
import { connect } from 'react-redux';
import { notify } from 'react-notify-toast';

import { updateLoading } from '../../store';

class ThemesTableItem extends React.Component {

  constructor( props ) {
    super(props);

    this.state = {
      copyText: 'Copy'
    };

    this.copyShortcode = this.copyShortcode.bind( this );
    this.deleteTheme = this.deleteTheme.bind( this );
  }

  render() {
    var item = this.props.item;

    return (
      <tr>
        <td className="gs-tcol-name"><NavLink to={"/themes/" + item.id}>{item.name}</NavLink></td>
        <td className="gs-tcol-shortcode"><span>[gs_instagram id="{item.id}"]</span><button onClick={() => this.copyShortcode()}>{this.state.copyText}</button></td>
        <td>{fecha.format(new Date(item.updated_at), 'longDate')}</td>
        <td className="gs-tcol-action">
          <NavLink to={"/themes/" + item.id}><span className="dashicons dashicons-edit"></span> <span>Edit</span></NavLink>
          <a href="#" onClick={this.deleteTheme}><span className="dashicons dashicons-trash"></span> <span>Delete</span></a>
        </td>
      </tr>
    );
  }

  copyShortcode() {
    var id = this.props.item.id;
    var el = document.createElement('textarea');
    el.value = '[gs_instagram id="' + id + '"]';
    document.body.appendChild(el);
    el.select();
    document.execCommand('copy');
    document.body.removeChild(el);

    this.setState({copyText: 'Copied'});
    setTimeout( () => {
      this.setState({copyText: 'Copy'});
    }, 5000 );
  }

  deleteTheme( event ) {
    event.preventDefault();
    var proceed = confirm('Are you sure to delete this theme?');
    if ( proceed ) {
      this.props.updateLoading( true );

      jQuery.ajax({
        method: "POST",
        url: window.ajaxurl,
        data: {
          body: { id: this.props.item.id },
          action: "gs_instagram_admin_ajax",
          route: "delete_theme",
        }
      }).done( ( response ) => {
        notify.show( 'Theme deleted successfully!', 'success' );
        this.props.removeItem( this.props.item.id );
      }).always( () => {
        this.props.updateLoading( false );
      });
    }
  }

}

function mapDispatchToProps( dispatch ) {
  return {
    updateLoading: value => dispatch( updateLoading( value ) ),
  };
}

export default connect(null, mapDispatchToProps)( ThemesTableItem );
