<?php

namespace GS_Instagram\Backend;

trait AjaxThemeHelper {

    /**
     * Create theme
     */
    public function create_theme( $data ) {
        $this->theme_form_validation( $data );

        global $wpdb;
        $table_name = $wpdb->prefix . 'gs_instagram_themes';

        $wpdb->insert( $table_name, [
            'name'        => $data['name'],
            'source'      => $data['source'],
            'source_type' => $data['source_type'],
            'per_page'    => $data['per_page'],
            'columns'     => $data['columns'],
            'theme_style' => $data['theme_style'],
            'link_target' => $data['link_target'],
            'meta_data'   => json_encode( $data['user_meta_data'] ),
            'updated_at'  => current_time( 'mysql' ),
        ] );

        wp_send_json_success();
    }

    /**
     * Update theme
     */
    public function update_theme( $data ) {
        $this->theme_form_validation( $data );

        global $wpdb;
        $table_name = $wpdb->prefix . 'gs_instagram_themes';

        $wpdb->update( $table_name, [
            'name'        => $data['name'],
            'source'      => $data['source'],
            'source_type' => $data['source_type'],
            'per_page'    => $data['per_page'],
            'columns'     => $data['columns'],
            'theme_style' => $data['theme_style'],
            'link_target' => $data['link_target'],
            'meta_data'   => json_encode( $data['user_meta_data'] ),
            'updated_at'  => current_time( 'mysql' ),
        ],
        [
            'id' => $data['id'],
        ] );

        delete_transient( 'gs_theme_' . $data['id'] . '_posts' );

        wp_send_json_success();
    }

    /**
     * Theme form valiation
     */
    private function theme_form_validation( $data ) {
        $message = null;

        if ( empty( $data['name'] ) ) {
            $message = 'Name field is required.';
        }

        if ( empty( $data['source'] ) ) {
            $message = 'Instagram source is required.';
        }

        if ( $message ) {
            wp_send_json_error( [ 'message' => $message ], 422 );
        }
    }

    /**
     * Delete theme
     */
    public function delete_theme( $data ) {
        if ( empty( $data['id'] ) ) {
            wp_send_json_error( [
                'message' => 'Theme not found.'
            ], 422 );
        }

        global $wpdb;
        $table_name = $wpdb->prefix . 'gs_instagram_themes';

        $wpdb->delete( $table_name, [ 'id' => $data['id'] ], [ '%d' ] );

        wp_send_json_success();
    }
}

