<?php

namespace GS_Instagram\Common;

use Exception;

class Curl {

    /**
     * @var string
     */
    protected $base_url = 'https://www.instagram.com';

    /**
     * @var string
     */
    protected $url;

    /**
     * Get graphql request enviorment
     */
    public static function graphql( $query_hash, $variables ) {
        $new_object = new self();

        $new_object->url = $new_object->base_url;
        $new_object->url .= '/graphql/query/?query_hash=' . $query_hash;
        $new_object->url .= '&variables=' . urlencode( json_encode( $variables ) );

        return $new_object;
    }

    /**
     * Send request to get user data
     */
    public function get_user_data() {
        $response = $this->request();

        $response = json_decode( $response, true );

        if ( ! isset( $response['data']['user'] ) ) {
            throw new Exception( 'Unable to fetch user media.', 103 );
        }

        if ( ! isset( $response['data']['user']['edge_owner_to_timeline_media'] ) ) {
            throw new Exception( 'No data found for this user.', 104 );
        }

        return $response['data']['user']['edge_owner_to_timeline_media'];
    }

    /**
     * Send request to get tag data
     */
    public function get_tag_data() {
        $response = $this->request();

        $response = json_decode( $response, true );

        if ( ! isset( $response['data']['hashtag']['edge_hashtag_to_media'] ) ) {
            throw new Exception( 'No data found for this tag.', 109 );
        }

        return $response['data']['hashtag']['edge_hashtag_to_media'];
    }

    /**
     * Request functionality
     */
    private function request( $full_response = false ) {
        $cookies = $this->get_cookies();

        $response = wp_remote_get( $this->url, $this->get_default_arguments( $cookies ) );

        if ( $full_response ) {
            return $response;
        }

        return wp_remote_retrieve_body( $response );
    }

    /**
     * html scrapper to get meta data
     */
    public static function scrap_source_html( $source ) {
        $new_object = new self();

        $new_object->url = $new_object->base_url;
        $new_object->url .= '/' . $source .  '/';

        return $new_object->request( true );
    }

    /**
     * Get security cookies
     */
    public function get_cookies( $credentials = null ) {
        $value = get_transient( 'gs_instagram_curl_cookies' );

        if ( false !== $value && ! empty( $value ) ) {
            return $value;
        }

        $site_results = $this->get_site_cookies();

        if ( empty( $site_results ) ) {
            return [];
        }

        set_transient( 'gs_instagram_curl_cookies', $site_results, DAY_IN_SECONDS );

        return $site_results;
    }

    /**
     * Get auth cookies
     */
    private function get_site_cookies() {
        $response = wp_remote_get( $this->base_url );
        $cookies = wp_remote_retrieve_cookies( $response );

        if ( ! is_array( $cookies ) ) {
            return [];
        }

        $results = [];

        foreach ( $cookies as $cookie ) {
            $results[ $cookie->name ] = $cookie->value;
        }

        if ( empty( $results ) ) {
            return [];
        }

        return $results;
    }

    /**
     * Get request default arguments
     */
    private function get_default_arguments( $cookies = [] ) {
        return [
            'method'      => 'GET',
            'timeout'     => 25,
            'redirection' => 5,
            'httpversion' => '1.1',
            'user-agent'  => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.120 Safari/537.36',
            'blocking'    => true,
            'sslverify'   => false,
            'headers'     => [
                'origin'           => 'https://www.instagram.com',
                'referer'          => 'https://www.instagram.com/',
                'x-requested-with' => 'XMLHttpRequest',
                'x-csrftoken'      => isset( $cookies['csrftoken'] ) ? $cookies['csrftoken'] : '',
            ],
            'cookies'     => $cookies,
            'body'        => [],
        ];
    }

}
