<?php

namespace GS_Instagram\Common;

use Exception;

class Instagram_Client {

    /**
     * Fetch data
     */
    public function fetch( $username = null, $limit = 12, $type = 'user', $end_cursor = '' ) {

        if ( ! $username ) {
            throw new Exception( 'Username or Tag not found.', 101 );
        }

        switch ( $type ) {
            case 'user':
                $feeds = $this->fetch_users_feed( $username, $limit, $end_cursor );
                break;

            case 'tag':
                $feeds = $this->fetch_tags_feed( $username, $limit, $end_cursor );
                break;

            default:
                throw new Exception( 'Invalid query type.', 102 );
        }

        $feeds['edges'] = $this->format_data( $feeds['edges'] );

        return $feeds;
    }

    /**
     * Get users data
     */
    private function fetch_users_feed( $user_id, $limit, $end_cursor ) {
        // $query_hash = 'f045d723b6f7f8cc299d62b57abd500a';
        $query_hash = 'e769aa130647d2354c40ea6a439bfc08';

        $variables = [
            'id'    => $user_id,
            'first' => ( $limit * 3 ),
            'after' => $end_cursor,
        ];

        return Curl::graphql( $query_hash, $variables )->get_user_data();
    }

    /**
     * Get tags data
     */
    private function fetch_tags_feed( $tag_name, $limit, $end_cursor ) {
        $query_hash = '174a5243287c5f3a7de741089750ab3b';

        $variables = [
            'tag_name' => $tag_name,
            'first'    => $limit,
            'after'    => $end_cursor,
        ];

        return Curl::graphql( $query_hash, $variables )->get_tag_data();
    }

    /**
     * Format data
     */
    private function format_data( $feeds ) {
        $new_feeds = [];

        foreach ( $feeds as $feed ) {
            if ( isset( $feed['node']['edge_media_to_caption']['edges'], $feed['node']['edge_media_to_caption']['edges'][0] ) ) {
                $text = $feed['node']['edge_media_to_caption']['edges'][0]['node']['text'];
            } else {
                $text = '';
            }

            $new_feeds[] = [
                'id'            => $feed['node']['id'],
                'display_url'   => $feed['node']['display_url'],
                'thumbnail_src' => $feed['node']['thumbnail_src'],
                'caption'       => preg_replace('/[[:^print:]]/', '', $text),
                'shortcode'     => $feed['node']['shortcode'],
                'comment_count' => $feed['node']['edge_media_to_comment']['count'],
                'like_count'    => $feed['node']['edge_media_preview_like']['count'],
            ];
        }

        return $new_feeds;
    }

    /**
     * Scrap meta data for user and tag
     */
    public function scrap_user_meta_data( $source ) {
        $response = Curl::scrap_source_html( $source );
        $html = wp_remote_retrieve_body( $response );

        preg_match( '/<script type="text\/javascript">window\._sharedData\s?=(.+);<\/script>/', $html, $matches );

        if ( ! isset( $matches[1] ) ) {
            error_log( '$response ==>>' . print_r( $response, 1 ) );
            error_log( '$matches ==>>' . print_r( $matches, 1 ) );
            throw new Exception( 'No user found for the given username.', 108 );
        }

        $data = json_decode( $matches[1], true );

        if ( $data === null ) {
            throw new Exception( json_last_error_msg(), 105 );
        }

        if ( isset( $data['entry_data']['LoginAndSignupPage'] ) ) {
            throw new Exception( 'Instagram blocked your IP.', 106 );
        }

        if ( ! isset( $data['entry_data']['ProfilePage'][0]['graphql']['user'] ) ) {
            throw new Exception( 'User could not found.', 107 );
        }

        $user = $data['entry_data']['ProfilePage'][0]['graphql']['user'];

        return [
            'user_id'        => $user['id'],
            'user_biography' => $user['biography'],
            'user_full_name' => $user['full_name'],
            'username'       => $user['username'],
            'profile_pic'    => $user['profile_pic_url_hd'],
        ];
    }

}
