<?php

namespace GS_Instagram;

/**
 * This class is responsible for load public funcitonality that will show on frontend
 */
class Frontend_Builder {

    /**
     * The single instance of the class.
     */
    protected static $_instance = null;

    /**
     * Initializes the Frontend_Builder() class
     *
     * Checks for an existing Frontend_Builder() instance and if it doesn't find one, creates it.
     */
    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }

    /**
     * Constructor of Frontend_Builder class
     * Sets up all the appropriate hooks
     */
    private function __construct() {
        $this->load_classes();

        add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_scripts' ], 10 );

        add_action( 'wp_ajax_gs_instagram_public_ajax', [ $this, 'ajax_handle' ] );
        add_action( 'wp_ajax_nopriv_gs_instagram_public_ajax', [ $this, 'ajax_handle' ] );
    }

    /**
     * Require necessary classes
     */
    private function load_classes() {
        // Shortcode
        require GS_INSTAGRAM_PUBLIC_PATH . '/includes/Shortcode.php';

        new Frontend\Shortcode();
    }

    /**
     * Frontend scripts
     */
    public function enqueue_scripts() {
        require GS_INSTAGRAM_PUBLIC_PATH . '/includes/Enqueue.php';

        new Frontend\Enqueue();
    }

    /**
     * Ajax handler
     */
    public function ajax_handle() {
        if ( ! isset( $_REQUEST['route'] ) ) {
            exit;
        }

        require GS_INSTAGRAM_PUBLIC_PATH . '/includes/Ajax.php';

        $ajax = new Frontend\Ajax();

        if ( method_exists( $ajax , $_REQUEST['route'] ) ) {
            $args = isset( $_REQUEST['body'] ) ? $_REQUEST['body'] : [];

            call_user_func( [ $ajax, $_REQUEST['route'] ], $args );
        }

        exit;
    }

}
