import React from 'react';
import { connect } from 'react-redux';

import Loading from './Loading';

import ThemePosts from '../themes/ThemePosts';

import { updateItems, updateNextPageStatus } from '../store';

class ThemeWrapper extends React.Component {

  constructor( props ) {
    super( props );

    this.state = {
      loadingMore: false,
      currentPage: 1,
    };

    this.getThemeComponent = this.getThemeComponent.bind(this);
    this.loadMore = this.loadMore.bind(this);
    this.loadMoreButton = this.loadMoreButton.bind(this);
  }

  render() {
    var Theme = this.getThemeComponent();

    return (
      <div className="gs-instagram-posts-wrapper">
        <Theme />
        { this.loadMoreButton() }
      </div>
    );
  }

  getThemeComponent() {
    if ( ! this.props.theme.theme_style ) {
      return Loading;
    }

    return ThemePosts;
  }

  loadMore() {
    this.setState( { loadingMore: true } );
    var currentPage = this.state.currentPage + 1;

    jQuery.ajax( {
      method: "GET",
      url: GS_Instagram.ajaxUrl,
      data: {
        action: 'gs_instagram_public_ajax',
        route: 'get_pagination_posts',
        body: {
          themeid: this.props.themeid,
          page: currentPage,
        },
      },
      success: ( response ) => {
        var newItems = this.props.items.concat( response.data.items );

        this.props.updateItems( newItems );
        this.props.updateNextPageStatus( response.data.has_next_page );
        this.setState( {
          loadingMore: false,
          currentPage: currentPage,
        } );
      }
    } );
  }

  loadMoreButton() {
    if ( ! GS_Instagram.show_load_more ) {
      return;
    }

    if ( ! this.props.hasNextPage ) {
      return;
    }

    return (
      <div className="gs-instagram-posts-loadmore">
        <button
          className={ "gsip-spinner-button ld-ext-right " + ( this.state.loadingMore ? 'running' : '' ) }
          type="button"
          onClick={this.loadMore}
        >
          <span>{GS_Instagram.load_more_text}</span>
          <span className="ld ld-ring ld-spin"></span>
        </button>
      </div>
    );
  }

}

function mapStateToProps( state ) {
  return {
    theme: state.theme,
    items: state.items,
    hasNextPage: state.hasNextPage,
  };
}

function mapDispatchToProps( dispatch ) {
  return {
    updateItems: value => dispatch( updateItems( value ) ),
    updateNextPageStatus: value => dispatch( updateNextPageStatus( value ) ),
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(ThemeWrapper);
